Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(51)

Unified Diff: chrome/test/data/android/payments/metrics.js

Issue 2220713002: [Payments] Add Payment Request metrics for selected payment method. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Addressed comments Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/test/data/android/payments/metrics.js
diff --git a/chrome/test/data/android/payments/metrics.js b/chrome/test/data/android/payments/metrics.js
index 3f12883863e05027c25f210f5a0bcd278d4faf5e..fe9dd0ab0b726b490af10b410d111ee1489f0c89 100644
--- a/chrome/test/data/android/payments/metrics.js
+++ b/chrome/test/data/android/payments/metrics.js
@@ -12,7 +12,7 @@ var request;
/**
* Launches the PaymentRequest UI that accepts credit cards.
*/
-function buy() { // eslint-disable-line no-unused-vars
+function ccBuy() { // eslint-disable-line no-unused-vars
try {
request = new PaymentRequest(
[{supportedMethods: ['visa']}], {
@@ -44,13 +44,12 @@ function buy() { // eslint-disable-line no-unused-vars
}
/**
* Launches the PaymentRequest UI which accepts a supported payment method but
* does not accept credit cards.
*/
-function noMatching() { // eslint-disable-line no-unused-vars
+function androidPayBuy() { // eslint-disable-line no-unused-vars
try {
request = new PaymentRequest(
- [{supportedMethods: ['https://bobpay.com']}], {
+ [{supportedMethods: ['https://android.com/pay']}], {
total: {label: 'Total', amount: {currency: 'USD', value: '5.00'}},
shippingOptions: [{
id: 'freeShippingOption',
@@ -44,13 +44,12 @@ function buy() { // eslint-disable-line no-unused-vars
}
/**
- * Launches the PaymentRequest UI which accepts a supported payment method but
- * does not accept credit cards.
+ * Launches the PaymentRequest UI which accepts only Android Pay.
*/

Powered by Google App Engine
This is Rietveld 408576698